aboutsummaryrefslogtreecommitdiffstats
path: root/tools/pwg_rel_create.sh
diff options
context:
space:
mode:
authormathiasm <mathiasm@piwigo.org>2008-01-24 22:00:56 +0000
committermathiasm <mathiasm@piwigo.org>2008-01-24 22:00:56 +0000
commitc1448de29e1c9700c58524021c075a023f6b9a6b (patch)
tree4fac08bcb6b198dfbfff9d4b0d032a250c0464c9 /tools/pwg_rel_create.sh
parent701bdfdc6581fc248af8373d556059ee7696022b (diff)
Fixed some inconsistencies in folder management
git-svn-id: http://piwigo.org/svn/trunk@2197 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'tools/pwg_rel_create.sh')
-rwxr-xr-xtools/pwg_rel_create.sh16
1 files changed, 12 insertions, 4 deletions
diff --git a/tools/pwg_rel_create.sh b/tools/pwg_rel_create.sh
index 3e69a7aa2..7fd1acc2c 100755
--- a/tools/pwg_rel_create.sh
+++ b/tools/pwg_rel_create.sh
@@ -26,7 +26,13 @@ then
rm -rf $name
fi
-# cvs export -r $tag -d $name phpwebgallery
+if [ -e $version ]
+then
+ rm -rf $version
+fi
+mkdir $version
+
+# cvs export -r $tag -d $version phpwebgallery
svn export http://svn.gna.org/svn/phpwebgallery/tags/$tag $name
# creating mysql.inc.php empty and writeable
touch $name/include/mysql.inc.php
@@ -36,6 +42,7 @@ chmod a+w $name/include/mysql.inc.php
# | xargs grep -l 'branch 1.7' \
# | xargs perl -pi -e "s/branch 1.7/${version}/g"
+cd /tmp/$version
for ext in zip tar.gz tar.bz2
do
file=$name.$ext
@@ -45,6 +52,7 @@ do
fi
done
-zip -r $name.zip $name
-tar -czf $name.tar.gz $name
-tar -cjf $name.tar.bz2 $name
+zip -r $name.zip ../$name
+tar -czf $name.tar.gz ../$name
+tar -cjf $name.tar.bz2 ../$name
+